TempoEvm

Struct TempoEvm 

pub struct TempoEvm<DB: Database, I> {
    pub inner: Evm<TempoContext<DB>, I, EthInstructions<EthInterpreter, TempoContext<DB>>, PrecompilesMap, EthFrame<EthInterpreter>>,
    pub logs: Vec<Log>,
    pub(crate) collected_fee: U256,
    pub(crate) initial_gas: u64,
}
TempoEvm extends the Evm with Tempo specific types and logic.

Fields

inner: Evm<TempoContext<DB>, I, EthInstructions<EthInterpreter, TempoContext<DB>>, PrecompilesMap, EthFrame<EthInterpreter>>

Inner EVM type.

logs: Vec<Log>

Preserved logs from the last transaction

collected_fee: U256

The fee collected in collectFeePreTx call.

initial_gas: u64

Initial gas cost. Used for key_authorization validation in collectFeePreTx.

Additional initial gas cost is added for authorization_key setting in pre execution.

Implementations

Source

impl<DB: Database, I> TempoEvm<DB, I>

pub fn new(ctx: TempoContext<DB>, inspector: I) -> Self

Create a new Tempo EVM.

fn new_inner( inner: Evm<TempoContext<DB>, I, EthInstructions<EthInterpreter, TempoContext<DB>>, PrecompilesMap, EthFrame<EthInterpreter>>, ) -> Self

Inner helper function to create a new Tempo EVM with empty logs.

Source

impl<DB: Database, I> TempoEvm<DB, I>

pub fn with_inspector<OINSP>(self, inspector: OINSP) -> TempoEvm<DB, OINSP>

Consumed self and returns a new Evm type with given Inspector.

pub fn with_precompiles(self, precompiles: PrecompilesMap) -> Self

Consumes self and returns a new Evm type with given Precompiles.

pub fn into_inspector(self) -> I

Consumes self and returns the inner Inspector.

pub fn take_logs(&mut self) -> Vec<Log>

Take logs from the EVM.