pub struct TempoEvm<DB: Database, I> {
pub inner: Evm<TempoContext<DB>, I, EthInstructions<EthInterpreter, TempoContext<DB>>, PrecompilesMap, EthFrame<EthInterpreter>>,
pub logs: Vec<Log>,
pub(crate) collected_fee: U256,
pub(crate) initial_gas: u64,
}Expand description
TempoEvm extends the Evm with Tempo specific types and logic.
Fields
inner: Evm<TempoContext<DB>, I, EthInstructions<EthInterpreter, TempoContext<DB>>, PrecompilesMap, EthFrame<EthInterpreter>>Inner EVM type.
logs: Vec<Log>Preserved logs from the last transaction
collected_fee: U256The fee collected in collectFeePreTx call.
initial_gas: u64Initial gas cost. Used for key_authorization validation in collectFeePreTx.
Additional initial gas cost is added for authorization_key setting in pre execution.
Implementations
Sourceimpl<DB: Database, I> TempoEvm<DB, I>
impl<DB: Database, I> TempoEvm<DB, I>
Sourcepub fn new(ctx: TempoContext<DB>, inspector: I) -> Self
pub fn new(ctx: TempoContext<DB>, inspector: I) -> Self
Create a new Tempo EVM.
Sourcefn new_inner(
inner: Evm<TempoContext<DB>, I, EthInstructions<EthInterpreter, TempoContext<DB>>, PrecompilesMap, EthFrame<EthInterpreter>>,
) -> Self
fn new_inner( inner: Evm<TempoContext<DB>, I, EthInstructions<EthInterpreter, TempoContext<DB>>, PrecompilesMap, EthFrame<EthInterpreter>>, ) -> Self
Inner helper function to create a new Tempo EVM with empty logs.
Sourceimpl<DB: Database, I> TempoEvm<DB, I>
impl<DB: Database, I> TempoEvm<DB, I>
Sourcepub fn with_inspector<OINSP>(self, inspector: OINSP) -> TempoEvm<DB, OINSP>
pub fn with_inspector<OINSP>(self, inspector: OINSP) -> TempoEvm<DB, OINSP>
Consumed self and returns a new Evm type with given Inspector.
Sourcepub fn with_precompiles(self, precompiles: PrecompilesMap) -> Self
pub fn with_precompiles(self, precompiles: PrecompilesMap) -> Self
Consumes self and returns a new Evm type with given Precompiles.
Sourcepub fn into_inspector(self) -> I
pub fn into_inspector(self) -> I
Consumes self and returns the inner Inspector.